Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5243)

Unified Diff: chrome/browser/chromeos/arc/arc_auth_service.h

Issue 2485233002: Do not run Android management check for re-auth case. (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/arc_auth_service.h
diff --git a/chrome/browser/chromeos/arc/arc_auth_service.h b/chrome/browser/chromeos/arc/arc_auth_service.h
index 8092f6090cde23dd27dc2855342210a28592af3b..2dc71d255e2bc75332bafaeb93dd7489040246c4 100644
--- a/chrome/browser/chromeos/arc/arc_auth_service.h
+++ b/chrome/browser/chromeos/arc/arc_auth_service.h
@@ -60,10 +60,12 @@ class ArcAuthService : public ArcService,
public sync_preferences::SyncedPrefObserver {
public:
enum class State {
Luis Héctor Chávez 2016/11/10 23:30:58 Can you add a state transition diagram here simila
hidehiko 2016/11/14 10:55:09 Done.
- NOT_INITIALIZED, // Service is not initialized.
- STOPPED, // ARC is not running.
- FETCHING_CODE, // ARC may be running or not. Auth code is fetching.
- ACTIVE, // ARC is running.
+ NOT_INITIALIZED, // Service is not initialized.
+ STOPPED, // ARC is not running.
+ TERMS, // Showing "Terms Of Service" to user.
Mr4D (OOO till 08-26) 2016/11/10 16:12:30 Could TERMS be replaced with something more expres
Luis Héctor Chávez 2016/11/10 23:30:58 Also, let's try to use a convention of using prese
hidehiko 2016/11/14 10:55:09 Done.
+ ANDROID_MANAGEMENT_CHECK, // Checkng Android management status.
Luis Héctor Chávez 2016/11/10 23:30:58 nit: s/Checkng/Checking/
hidehiko 2016/11/14 10:55:09 Done.
+ FETCHING_CODE, // ARC is not yet running. Fetching auth token.
+ ACTIVE, // ARC is running.
};
class Observer {
@@ -183,6 +185,7 @@ class ArcAuthService : public ArcService,
bool is_backup_and_restore_enabled,
bool is_location_service_enabled) override;
void OnAuthSucceeded(const std::string& auth_code) override;
+ void OnRetryClicked() override;
void OnSendFeedbackClicked() override;
// arc::ArcOptInPreferenceHandlerObserver:
@@ -226,7 +229,6 @@ class ArcAuthService : public ArcService,
const base::string16& status);
void OnOptInPreferenceChanged();
void StartUI();
- void StartAndroidManagementClient();
hidehiko 2016/11/10 01:46:23 Note: No implemention. No usage...
void OnAndroidManagementPassed();
void OnArcDataRemoved(bool success);
void OnArcSignInTimeout();
@@ -237,6 +239,8 @@ class ArcAuthService : public ArcService,
std::unique_ptr<AccountInfoNotifier> account_info_notifier);
void OnAccountInfoReady(mojom::AccountInfoPtr account_info);
+ void StartArcAndroidManagementCheck();
+
// Called when the Android management check is done in opt-in flow or
// re-auth flow.
void OnAndroidManagementChecked(
« no previous file with comments | « no previous file | chrome/browser/chromeos/arc/arc_auth_service.cc » ('j') | chrome/browser/chromeos/arc/arc_auth_service.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698